#
# spec file for package zeromq
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lib_name libzmq4
%ifarch %ix86 x86_64
%define with_pgm 1
%endif
Name:           zeromq
Version:        4.0.8
Release:        5.1
Summary:        Lightweight messaging kernel
License:        LGPL-3.0+
Group:          Productivity/Networking/Web/Servers
Url:            http://www.zeromq.org/
Source:         http://download.zeromq.org/%{name}-%{version}.tar.gz

Patch1:         zeromq-CVE-2014-7203.patch

BuildRequires:  gcc-c++
BuildRequires:  libuuid-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?with_pgm}
BuildRequires:  pkgconfig
BuildRequires:  python
%if 0%{?suse_version} && 0%{?suse_version} < 1130
BuildRequires:  glib2 >= 2.8
%else
BuildRequires:  pkgconfig(glib-2.0) >= 2.8
%endif
%endif

%description
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialised messaging middleware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging patterns,
message filtering (subscriptions), seamless access to multiple transport
protocols and more.

%package -n %{lib_name}
Summary:        Shared Library for ZeroMQ
Group:          Productivity/Networking/Web/Servers

%description -n %{lib_name}
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialised messaging middleware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging patterns,
message filtering (subscriptions), seamless access to multiple transport
protocols and more.

This package holds the shared library part of the ZeroMQ package.

%package devel
Summary:        Development files for ZeroMQ
Group:          Development/Languages/C and C++
Requires:       %{lib_name} = %{version}
Provides:       libzmq-devel = %{version}

%description devel
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialised messaging middleware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging patterns,
message filtering (subscriptions), seamless access to multiple transport
protocols and more.

This package holds the development files for ZeroMQ.

%prep
%setup -q

%patch1 -p1

%build
%configure \
  --disable-silent-rules \
%if 0%{?with_pgm}
  --with-pgm \
%endif
  --disable-static \
  --with-pic
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

%check
make check %{?_smp_mflags}

%post -n %{lib_name} -p /sbin/ldconfig

%postun -n %{lib_name} -p /sbin/ldconfig

%files -n %{lib_name}
%defattr(-,root,root,-)
%doc COPYING COPYING.LESSER
%{_libdir}/libzmq.so.*
%{_bindir}/curve_keygen

%files devel
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING COPYING.LESSER NEWS
%{_includedir}/zmq*
%{_libdir}/libzmq.so
%{_libdir}/pkgconfig/libzmq.pc

%changelog
* Thu Jun 23 2016 kkaempf@suse.com
- rename to libzmq4 to match .so name
* Wed Jun 22 2016 kkaempf@suse.com
- remove upstreamed patches: zeromq-CVE-2014-7202.patch
  zeromq_4.0.5_avoid_curve_test_hang_on_ppc64.patch
- 0MQ version 4.0.8 stable, released on 2016/06/17
  * Fixed LIBZMQ-949 - zmq_unbind fails for inproc and wildcard endpoints
  * Fixed #1806 - uninitialised read in curve getsockopt.
  * Fixed #1807 - build broken with GCC 6.
  * Fixed #1877 - Avoid terminating connections prematurely
  * Fixed #1887 - zmq_bind IPv4 fallback still tries IPv6
  * Fixed #98 - don't require libssp without libsodium on Solaris
  * Fixed #919 - ZMQ_LINGER (related to #1877)
  * Fixed #139 - "tempnam" is deprecated.
  0MQ version 4.0.7 stable, released on 2015/06/15
  * Fixed #1428 - regression on single-socket proxies.
  0MQ version 4.0.6 stable, released on 2015/06/02
  * Fixed #1273 - V3 protocol handler vulnerable to downgrade attacks.
  * Fixed #1362 - SUB socket sometimes fails to resubscribe properly.
  * Fixed #1377, #1144 - failed with WSANOTINITIALISED in some cases.
  * Fixed #1389 - PUB, PUSH sockets had slow memory leak.
  * Fixed #1382 - zmq_proxy did not terminate if there were no readers.
  0MQ version 4.0.5 stable, released on 2014/10/14
  * Fixed #1191; CURVE mechanism does not verify short term nonces.
  * Fixed #1190; stream_engine is vulnerable to downgrade attacks.
  * Fixed #1088; assertion failure for WSAENOTSOCK on Windows.
  * Fixed #1015; race condition while connecting inproc sockets.
  * Fixed #994; bump so library number to 4.0.0
  * Fixed #939, assertion failed: !more (fq.cpp:99) after many ZAP requests.
  * Fixed #872; lost first part of message over inproc://.
  * Fixed #797, keep-alive on Windows.
* Mon Jun  1 2015 tchvatal@suse.com
- Add a zeromq_4.0.5_avoid_curve_test_hang_on_ppc64.patch
  to avoid curve test to hang for ppc ppc64 ppc64le architectures
  related bug ref: bnc#912460
  This is a set of commits grab from zeromq4-x git tree
  from https://github.com/zeromq/zeromq4-x.git
    Merge pull request #101 from hintjens/master
    Problem: issue #1273, protocol downgrade attack
    Merge pull request #100 from hintjens/master
    Problem: zmq_ctx_term has insane behavior by default
  * Also fixes bnc#931978 CVE-2014-9721
* Mon Sep 29 2014 tchvatal@suse.com
- Add patches to fix CVE-2014-7202 and CVE-2014-7203.
  Fixes bnc#898917
  * zeromq-CVE-2014-7202.patch
  * zeromq-CVE-2014-7203.patch
* Mon May 12 2014 tchvatal@suse.com
- Cleanup to remove SLE10 and older mentions
- Remove other distros from rules as we don't build for them anyway.
- Cleanup with spec-cleaner.
- Enable tests.
* Thu Mar 27 2014 speilicke@suse.com
- Move to 'download_files' source service which is in better shap
  and easier to use
* Thu Mar 27 2014 mvyskocil@opensuse.org
- Update to 4.0.4
  For details see /usr/share/doc/packages/zeromq-devel/NEWS
- Moved most of docs to devel package to reduce a size of libmq3
* Fri Dec 13 2013 bahid@emc.com
- Update to version 4.0.3
  For details see /usr/share/doc/packages/libzmq3/NEWS
* Sat Sep 21 2013 p.drouand@gmail.com
- Update to version 3.2.4
  For details see /usr/share/doc/packages/libzmq3/NEWS
* Fri Nov 23 2012 mrueckert@suse.de
- Update to version 3.2.2
  For details see /usr/share/doc/packages/libzmq3/NEWS
* Sat Jan 28 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Wed Sep 28 2011 saschpe@gmx.de
- Fixed license to LGPL-3.0+ (SPDX style)
* Wed Aug 24 2011 mrueckert@suse.de
- make sure the compiler commandlines are shown (V=1)
- make it build on sle11 again. we dont have pkg-config provides
  there
* Fri Aug 19 2011 saschpe@suse.de
- Use %%makeinstall marcro instead of %%make_install to fix build
  on Mandriva and Fedora
* Fri Aug 19 2011 saschpe@suse.de
- Add libuuid-devel to RedHat BuildRequires to fix build
* Fri Aug 19 2011 saschpe@suse.de
- Update to version 2.1.7:
  * Fixed issue 188, assert when closing socket that had unread multipart
    data still on it (affected PULL, SUB, ROUTER, and DEALER sockets).
  * Fixed issue 191, message atomicity issue with PUB sockets (an old issue).
  * Fixed issue 199 (affected ROUTER/XREP sockets, an old issue).
  * Fixed issue 206, assertion failure in zmq.cpp:223, affected all sockets
    (bug was introduced in 2.1.6 as part of message validity checking).
  * Fixed issue 211, REP socket asserted if sent malformed envelope (old issue
    due to abuse of assertions for error checking).
  * Fixed issue 212, reconnect failing after resume from sleep on Windows
    (due to not handling WSAENETDOWN).
  * Properly handle WSAENETUNREACH on Windows (e.g. if client connects
    before server binds).
  * Fixed memory leak with threads on Windows.
- Changes from previous releases:
  * See https://raw.github.com/zeromq/zeromq2-1/master/NEWS
- Run spec-cleaner, added proper spec license header, shorter file lists
- Split out documentation package
* Wed Dec  1 2010 mrueckert@suse.de
- update to version 2.0.10
  * Upgrade OpenPGM to 2.1.28~dfsg (Martin Lucina)
  * Added a ZMQ_VERSION macro to zmq.h for compile-time API version
    detection (Martin Sustrik, Gonzalo Diethelm, Martin Lucina)
  * Fix memory leak under Windows (Taras Shpot)
  * Makefile.am: Add missing files to distribution, improve
    maintainer-clean (Martin Lucina)
  * Add support for RHEL6 in the spec file (Sebastian Otaegui)
  * configure.in: Do not patch libtool rpath handling (Martin Lucina)
  * Fixing the Red Hat packaging (Martin Sustrik)
  * zmq_msg_move called on uninitialised message in xrep_t::xrecv
  - - fixed (Max Wolf)
  * crash when closing an ypipe -- fixed (Dhammika Pathirana)
  * REQ socket can die when reply is delivered on wrong unerlying
    connection -- fixed (Martin Sustrik)
  * if TSC jumps backwards (in case of migration to a
    different CPU core) latency peak may occur -- fixed
    (Martin Sustrik)
  * values of RATE, RECOVERY_IVL and SWAP options are checked for
    negative values (Martin Sustrik)
- added provides for libzmq-devel
* Mon Sep  6 2010 mrueckert@suse.de
- initial package
